# Dev installation

Ensure `uv` is installed:

```
which uv
```

If not, this can be installed following instructions [here](https://docs.astral.sh/uv/getting-started/installation/).

Then run:

```
git clone https://github.com/washu-ocean/cnda-dl.git
cd cnda-dl
uv sync
```
